## Simple decentralized custom code execution

This sample application lets you write code and send it to a processing node in the Neural Edge Protocol network where the code is executed and the results are returned. This simple UI is provided by a ratio1 Edge Protocol decentralized processing node as well. Choose a code template or write your own code:
Code Template:
Tab Indent Size:
Executing...
Result: